@@ -7,7 +7,6 @@ Interfaces for L{twisted.mail}.
 @since: 16.5
 """
 
-from __future__ import absolute_import, division
 
 from zope.interface import Interface
 
@@ -25,7 +24,6 @@ class IChallengeResponse(Interface):
         @rtype: L{bytes}
         """
 
-
     def setResponse(response):
         """
         Extract a username and possibly a password from a response and
@@ -38,7 +36,6 @@ class IChallengeResponse(Interface):
             L{credentials.IUsernameHashedPassword}
         """
 
-
     def moreChallenges():
         """
         Are there more challenges than just the first?  If so, callers
@@ -51,9 +48,7 @@ class IChallengeResponse(Interface):
         """
 
 
-
 class IClientAuthentication(Interface):
-
     def getName():
         """
         Return an identifier associated with this authentication scheme.
@@ -67,7 +62,6 @@ class IClientAuthentication(Interface):
         """
 
 
-
 class IServerFactoryPOP3(Interface):
     """
     An interface for querying capabilities of a POP3 server.
@@ -84,6 +78,7 @@ class IServerFactoryPOP3(Interface):
         L{IUsernameHashedPassword <cred.credentials.IUsernameHashedPassword>}
         provider.
     """
+
     def cap_IMPLEMENTATION():
         """
         Return a string describing the POP3 server implementation.
@@ -92,7 +87,6 @@ class IServerFactoryPOP3(Interface):
         @return: Server implementation information.
         """
 
-
     def cap_EXPIRE():
         """
         Return the minimum number of days messages are retained.
@@ -102,7 +96,6 @@ class IServerFactoryPOP3(Interface):
             the server never deletes messages.
         """
 
-
     def perUserExpiration():
         """
         Indicate whether the message expiration policy differs per user.
@@ -112,7 +105,6 @@ class IServerFactoryPOP3(Interface):
             C{False} otherwise.
         """
 
-
     def cap_LOGIN_DELAY():
         """
         Return the minimum number of seconds between client logins.
@@ -121,7 +113,6 @@ class IServerFactoryPOP3(Interface):
         @return: The minimum number of seconds between client logins.
         """
 
-
     def perUserLoginDelay():
         """
         Indicate whether the login delay period differs per user.
@@ -132,7 +123,6 @@ class IServerFactoryPOP3(Interface):
         """
 
 
-
 class IMailboxPOP3(Interface):
     """
     An interface for mailbox access.
@@ -147,6 +137,7 @@ class IMailboxPOP3(Interface):
     @ivar messageExpiration: The number of days messages in this mailbox will
         remain on the server before being deleted.
     """
+
     def listMessages(index=None):
         """
         Retrieve the size of a message, or, if none is specified, the size of
@@ -166,7 +157,6 @@ class IMailboxPOP3(Interface):
             a message in the mailbox.  The use of ValueError is preferred.
         """
 
-
     def getMessage(index):
         """
         Retrieve a file containing the contents of a message.
@@ -181,7 +171,6 @@ class IMailboxPOP3(Interface):
             a message in the mailbox.  The use of ValueError is preferred.
         """
 
-
     def getUidl(index):
         """
         Get a unique identifier for a message.
@@ -197,7 +186,6 @@ class IMailboxPOP3(Interface):
             a message in the mailbox.  The use of ValueError is preferred.
         """
 
-
     def deleteMessage(index):
         """
         Mark a message for deletion.
@@ -213,7 +201,6 @@ class IMailboxPOP3(Interface):
             a message in the mailbox.  The use of ValueError is preferred.
         """
 
-
     def undeleteMessages():
         """
         Undelete all messages marked for deletion.
@@ -222,18 +209,17 @@ class IMailboxPOP3(Interface):
         position in the message sequence and retain its original UID.
         """
 
-
     def sync():
         """
         Discard the contents of any message marked for deletion.
         """
 
 
-
 class IDomain(Interface):
     """
     An interface for email domains.
     """
+
     def exists(user):
         """
         Check whether a user exists in this domain.
@@ -248,7 +234,6 @@ class IDomain(Interface):
         @raise SMTPBadRcpt: When the given user does not exist in this domain.
         """
 
-
     def addUser(user, password):
         """
         Add a user to this domain.
@@ -260,7 +245,6 @@ class IDomain(Interface):
         @param password: A password.
         """
 
-
     def getCredentialsCheckers():
         """
         Return credentials checkers for this domain.
@@ -271,11 +255,11 @@ class IDomain(Interface):
         """
 
 
-
 class IAlias(Interface):
     """
     An interface for aliases.
     """
+
     def createMessageReceiver():
         """
         Create a message receiver.
@@ -285,11 +269,11 @@ class IAlias(Interface):
         """
 
 
-
 class IAliasableDomain(IDomain):
     """
     An interface for email domains which can be aliased to other domains.
     """
+
     def setAliasGroup(aliases):
         """
         Set the group of defined aliases for this domain.
@@ -298,7 +282,6 @@ class IAliasableDomain(IDomain):
         @param aliases: A mapping of domain name to alias.
         """
 
-
     def exists(user, memo=None):
         """
         Check whether a user exists in this domain or an alias of it.
@@ -321,9 +304,7 @@ class IAliasableDomain(IDomain):
         """
 
 
-
 class IMessageDelivery(Interface):
-
     def receivedHeader(helo, origin, recipients):
         """
         Generate the Received header for a message.
@@ -380,7 +361,6 @@ class IMessageDelivery(Interface):
         """
 
 
-
 class IMessageDeliveryFactory(Interface):
     """
     An alternate interface to implement for handling message delivery.
@@ -392,6 +372,7 @@ class IMessageDeliveryFactory(Interface):
     be done by L{IMessageDelivery} implementors due to their lack of
     information.
     """
+
     def getMessageDelivery():
         """
         Return an L{IMessageDelivery} object.
@@ -400,7 +381,6 @@ class IMessageDeliveryFactory(Interface):
         """
 
 
-
 class IMessageSMTP(Interface):
     """
     Interface definition for messages that can be sent via SMTP.
@@ -429,7 +409,6 @@ class IMessageSMTP(Interface):
         """
 
 
-
 class IMessageIMAPPart(Interface):
     def getHeaders(negate, *names):
         """
@@ -446,13 +425,11 @@ class IMessageIMAPPart(Interface):
         @return: A mapping of header field names to header field values
         """
 
-
     def getBodyFile():
         """
         Retrieve a file object containing only the body of this message.
         """
 
-
     def getSize():
         """
         Retrieve the total size, in octets, of this message.
@@ -460,7 +437,6 @@ class IMessageIMAPPart(Interface):
         @rtype: L{int}
         """
 
-
     def isMultipart():
         """
         Indicate whether this message has subparts.
@@ -468,7 +444,6 @@ class IMessageIMAPPart(Interface):
         @rtype: L{bool}
         """
 
-
     def getSubPart(part):
         """
         Retrieve a MIME sub-message
@@ -484,15 +459,12 @@ class IMessageIMAPPart(Interface):
         """
 
 
-
 class IMessageIMAP(IMessageIMAPPart):
-
     def getUID():
         """
         Retrieve the unique identifier associated with this message.
         """
 
-
     def getFlags():
         """
         Retrieve the flags associated with this message.
@@ -501,7 +473,6 @@ class IMessageIMAP(IMessageIMAPPart):
         @return: The flags, represented as strings.
         """
 
-
     def getInternalDate():
         """
         Retrieve the date internally associated with this message.
@@ -511,7 +482,6 @@ class IMessageIMAP(IMessageIMAPPart):
         """
 
 
-
 class IMessageIMAPFile(Interface):
     """
     Optional message interface for representing messages as files.
@@ -529,9 +499,7 @@ class IMessageIMAPFile(Interface):
         """
 
 
-
 class ISearchableIMAPMailbox(Interface):
-
     def search(query, uid):
         """
         Search for messages that meet the given query criteria.
@@ -559,7 +527,6 @@ class ISearchableIMAPMailbox(Interface):
         """
 
 
-
 class IMailboxIMAPListener(Interface):
     """
     Interface for objects interested in mailbox events
@@ -574,7 +541,6 @@ class IMailboxIMAPListener(Interface):
             otherwise.
         """
 
-
     def flagsChanged(newFlags):
         """
         Indicates that the flags of one or more messages have changed.
@@ -584,7 +550,6 @@ class IMailboxIMAPListener(Interface):
             now set on that message.
         """
 
-
     def newMessages(exists, recent):
         """
         Indicates that the number of messages in a mailbox has changed.
@@ -599,7 +564,6 @@ class IMailboxIMAPListener(Interface):
         """
 
 
-
 class IMessageIMAPCopier(Interface):
     def copy(messageObject):
         """
@@ -620,7 +584,6 @@ class IMessageIMAPCopier(Interface):
         """
 
 
-
 class IMailboxIMAPInfo(Interface):
     """
     Interface specifying only the methods required for C{listMailboxes}.
@@ -641,7 +604,6 @@ class IMailboxIMAPInfo(Interface):
             mailbox.
         """
 
-
     def getHierarchicalDelimiter():
         """
         Get the character which delimits namespaces for in this mailbox.
@@ -650,7 +612,6 @@ class IMailboxIMAPInfo(Interface):
         """
 
 
-
 class IMailboxIMAP(IMailboxIMAPInfo):
     def getUIDValidity():
         """
@@ -659,7 +620,6 @@ class IMailboxIMAP(IMailboxIMAPInfo):
         @rtype: L{int}
         """
 
-
     def getUIDNext():
         """
         Return the likely UID for the next message added to this mailbox.
@@ -667,7 +627,6 @@ class IMailboxIMAP(IMailboxIMAPInfo):
         @rtype: L{int}
         """
 
-
     def getUID(message):
         """
         Return the UID of a message in the mailbox
@@ -679,7 +638,6 @@ class IMailboxIMAP(IMailboxIMAPInfo):
         @return: The UID of the message.
         """
 
-
     def getMessageCount():
         """
         Return the number of messages in this mailbox.
@@ -687,7 +645,6 @@ class IMailboxIMAP(IMailboxIMAPInfo):
         @rtype: L{int}
         """
 
-
     def getRecentCount():
         """
         Return the number of messages with the 'Recent' flag.
@@ -695,7 +652,6 @@ class IMailboxIMAP(IMailboxIMAPInfo):
         @rtype: L{int}
         """
 
-
     def getUnseenCount():
         """
         Return the number of messages with the 'Unseen' flag.
@@ -703,7 +659,6 @@ class IMailboxIMAP(IMailboxIMAPInfo):
         @rtype: L{int}
         """
 
-
     def isWriteable():
         """
         Get the read/write status of the mailbox.
@@ -713,7 +668,6 @@ class IMailboxIMAP(IMailboxIMAPInfo):
             otherwise.
         """
 
-
     def destroy():
         """
         Called before this mailbox is deleted, permanently.
@@ -722,7 +676,6 @@ class IMailboxIMAP(IMailboxIMAPInfo):
         here. This function _must_ set the \\Noselect flag on this mailbox.
         """
 
-
     def requestStatus(names):
         """
         Return status information about this mailbox.
@@ -744,7 +697,6 @@ class IMailboxIMAP(IMailboxIMAPInfo):
             passed this dictionary is returned instead.
         """
 
-
     def addListener(listener):
         """
         Add a mailbox change listener
@@ -754,7 +706,6 @@ class IMailboxIMAP(IMailboxIMAPInfo):
             notified when the contents of this mailbox change.
         """
 
-
     def removeListener(listener):
         """
         Remove a mailbox change listener
@@ -767,8 +718,7 @@ class IMailboxIMAP(IMailboxIMAPInfo):
             this mailbox.
         """
 
-
-    def addMessage(message, flags=(), date=None):
+    def addMessage(message, flags, date):
         """
         Add the given message to this mailbox.
 
@@ -790,7 +740,6 @@ class IMailboxIMAP(IMailboxIMAPInfo):
             read-write.
         """
 
-
     def expunge():
         """
         Remove all messages flagged \\Deleted.
@@ -803,7 +752,6 @@ class IMailboxIMAP(IMailboxIMAPInfo):
             read-write.
         """
 
-
     def fetch(messages, uid):
         """
         Retrieve one or more messages.
@@ -820,7 +768,6 @@ class IMailboxIMAP(IMailboxIMAPInfo):
             implementors of C{IMessageIMAP}.
         """
 
-
     def store(messages, flags, mode, uid):
         """
         Set the flags of one or more messages.
@@ -852,7 +799,6 @@ class IMailboxIMAP(IMailboxIMAPInfo):
         """
 
 
-
 class ICloseableMailboxIMAP(Interface):
     """
     A supplementary interface for mailboxes which require cleanup on close.
@@ -870,7 +816,6 @@ class ICloseableMailboxIMAP(Interface):
         """
 
 
-
 class IAccountIMAP(Interface):
     """
     Interface for Account classes
@@ -900,7 +845,6 @@ class IAccountIMAP(Interface):
             L{Deferred} is returned.
         """
 
-
     def create(pathspec):
         """
         Create a new mailbox from the given hierarchical name.
@@ -918,7 +862,6 @@ class IAccountIMAP(Interface):
             may also be raised asynchronously, if a L{Deferred} is returned.
         """
 
-
     def select(name, rw=True):
         """
         Acquire a mailbox, given its name.
@@ -936,7 +879,6 @@ class IAccountIMAP(Interface):
             specified mailbox may not be selected for any reason.
         """
 
-
     def delete(name):
         """
         Delete the mailbox with the specified name.
@@ -953,7 +895,6 @@ class IAccountIMAP(Interface):
             may also be raised asynchronously, if a L{Deferred} is returned.
         """
 
-
     def rename(oldname, newname):
         """
         Rename a mailbox
@@ -973,7 +914,6 @@ class IAccountIMAP(Interface):
             may also be raised asynchronously, if a L{Deferred} is returned.
         """
 
-
     def isSubscribed(name):
         """
         Check the subscription status of a mailbox
@@ -987,7 +927,6 @@ class IAccountIMAP(Interface):
             callback will be invoked with one of these values.
         """
 
-
     def subscribe(name):
         """
         Subscribe to a mailbox
@@ -1005,7 +944,6 @@ class IAccountIMAP(Interface):
             returned.
         """
 
-
     def unsubscribe(name):
         """
         Unsubscribe from a mailbox
@@ -1023,7 +961,6 @@ class IAccountIMAP(Interface):
             returned.
         """
 
-
     def listMailboxes(ref, wildcard):
         """
         List all the mailboxes that meet a certain criteria
@@ -1045,9 +982,7 @@ class IAccountIMAP(Interface):
         """
 
 
-
 class INamespacePresenter(Interface):
-
     def getPersonalNamespaces():
         """
         Report the available personal namespaces.
@@ -1060,7 +995,6 @@ class INamespacePresenter(Interface):
             no namespaces of this type exist, None should be returned.
         """
 
-
     def getSharedNamespaces():
         """
         Report the available shared namespaces.
@@ -1074,7 +1008,6 @@ class INamespacePresenter(Interface):
             namespaces of this type exist, None should be returned.
         """
 
-
     def getUserNamespaces():
         """
         Report the available user namespaces.
@@ -1088,23 +1021,30 @@ class INamespacePresenter(Interface):
         """
 
 
-
 __all__ = [
     # IMAP
-    'IAccountIMAP', 'ICloseableMailboxIMAP', 'IMailboxIMAP',
-    'IMailboxIMAPInfo', 'IMailboxIMAPListener', 'IMessageIMAP',
-    'IMessageIMAPCopier', 'IMessageIMAPFile', 'IMessageIMAPPart',
-    'ISearchableIMAPMailbox', 'INamespacePresenter',
-
+    "IAccountIMAP",
+    "ICloseableMailboxIMAP",
+    "IMailboxIMAP",
+    "IMailboxIMAPInfo",
+    "IMailboxIMAPListener",
+    "IMessageIMAP",
+    "IMessageIMAPCopier",
+    "IMessageIMAPFile",
+    "IMessageIMAPPart",
+    "ISearchableIMAPMailbox",
+    "INamespacePresenter",
     # SMTP
-    'IMessageDelivery', 'IMessageDeliveryFactory', 'IMessageSMTP',
-
+    "IMessageDelivery",
+    "IMessageDeliveryFactory",
+    "IMessageSMTP",
     # Domains and aliases
-    'IDomain', 'IAlias', 'IAliasableDomain',
-
+    "IDomain",
+    "IAlias",
+    "IAliasableDomain",
     # POP3
-    'IMailboxPOP3', 'IServerFactoryPOP3',
-
+    "IMailboxPOP3",
+    "IServerFactoryPOP3",
     # Authentication
-    'IClientAuthentication',
+    "IClientAuthentication",
 ]
